@@ -7,6 +7,8 @@ from nomad_pilot_cli.api.batch_api import BatchApi
 from nomad_pilot_cli.api.callback_api import CallbackApi
 from nomad_pilot_cli.api.carriers_api import CarriersApi
 from nomad_pilot_cli.api.freight_forward_api import FreightForwardApi
+from nomad_pilot_cli.api.inventory_api import InventoryApi
+from nomad_pilot_cli.api.inventory_purchase_api import InventoryPurchaseApi
 from nomad_pilot_cli.api.quick_ship_api import QuickShipApi
 from nomad_pilot_cli.api.ship_api import ShipApi
 from nomad_pilot_cli.api.ship_confirm_api import ShipConfirmApi
